@@ -28,6 +28,7 @@ Webhooks = None
 TransactionNotifications = None
 ResultHandler = None
 Polling = None
+__version__ = '1.2.0'
 
 
 def initialize(client_id, client_secret, base_url, api_secret=None):
@@ -45,6 +46,7 @@ def initialize(client_id, client_secret, base_url, api_secret=None):
     validation.validate_string_arguments(client_id,
                                          client_secret,
                                          base_url)
+    validation.validate_base_url(base_url)
 
     # initialize  token service
     globals()['Tokens'] = TokenService(client_id=client_id,
